summaryrefslogtreecommitdiffstats
path: root/devtools/client/debugger/src/selectors/breakpointSources.js
diff options
context:
space:
mode:
Diffstat (limited to 'devtools/client/debugger/src/selectors/breakpointSources.js')
-rw-r--r--devtools/client/debugger/src/selectors/breakpointSources.js6
1 files changed, 2 insertions, 4 deletions
diff --git a/devtools/client/debugger/src/selectors/breakpointSources.js b/devtools/client/debugger/src/selectors/breakpointSources.js
index a0daedae21..4867ade82c 100644
--- a/devtools/client/debugger/src/selectors/breakpointSources.js
+++ b/devtools/client/debugger/src/selectors/breakpointSources.js
@@ -5,7 +5,6 @@
import { createSelector } from "devtools/client/shared/vendor/reselect";
import { getSelectedSource } from "./sources";
import { getBreakpointsList } from "./breakpoints";
-import { getFilename } from "../utils/source";
import { getSelectedLocation } from "../utils/selected-location";
// Returns a list of sources with their related breakpoints:
@@ -37,16 +36,15 @@ export const getBreakpointSources = createSelector(
sources.set(source, {
source,
breakpoints: [breakpoint],
- filename: getFilename(source),
});
} else {
sources.get(source).breakpoints.push(breakpoint);
}
}
// Returns an array of breakpoints info per source, sorted by source's filename
return [...sources.values()].sort((a, b) =>
- a.filename.localeCompare(b.filename)
+ a.source.shortName.localeCompare(b.source.shortName)
);
}
);
@@ -37,16 +36,15 @@ export const getBreakpointSources = createSelector(
}
}
- // Returns an array of breakpoints info per source, sorted by source's filename
+ // Returns an array of breakpoints info per source, sorted by source's displayed name
return [...sources.values()].sort((a, b) =>